@@ -17,7 +17,7 @@
 #  along with Pyrogram.  If not, see <http://www.gnu.org/licenses/>.
 
 from datetime import datetime
-from typing import Union, List, Optional, AsyncGenerator, BinaryIO, Dict
+from typing import Union, List, Optional, AsyncGenerator, BinaryIO
 
 import pyrogram
 from pyrogram import raw, enums
@@ -36,9 +36,15 @@ class Chat(Object):
         type (:obj:`~pyrogram.enums.ChatType`):
             Type of chat.
 
+        is_forum (``bool``, *optional*):
+            True, if the supergroup chat is a forum
+
         is_verified (``bool``, *optional*):
             True, if this chat has been verified by Telegram. Supergroups, channels and bots only.
 
+        is_participants_hidden (``bool``, *optional*):
+            True, if the chat members are hidden.
+
         is_restricted (``bool``, *optional*):
             True, if this chat has been restricted. Supergroups, channels and bots only.
             See *restriction_reason* for details.
@@ -55,35 +61,17 @@ class Chat(Object):
         is_fake (``bool``, *optional*):
             True, if this chat has been flagged for impersonation.
 
+        is_deactivated (``bool``, *optional*):
+            True, if this chat has been flagged for deactivated.
+
         is_support (``bool``):
             True, if this chat is part of the Telegram support team. Users and bots only.
 
-        is_participants_hidden (``bool``, *optional*):
-            True, if the chat members are hidden.
-            Returned only in :meth:`~pyrogram.Client.get_chat`.
+        is_stories_hidden (``bool``):
+            True, if this chat has hidden stories.
 
-        is_join_request (``bool``, *optional*):
-            True, if the admin need to approve member(s) join request.
-
-        is_join_to_send (``bool``, *optional*):
-            True, if only chat members allowed to send message in chat.
-
-        is_slowmode_enabled (``bool``, *optional*):
-            True, if slowmode is enabled in chat.
-
-        is_antispam (``bool``, *optional*):
-            True, if Aggressive Anti-Spam is enabled in chat.
-            Returned only in :meth:`~pyrogram.Client.get_chat`.
-
-        is_paid_reactions_available (``bool``, *optional*):
-            True, if paid reactions are available in chat.
-            Returned only in :meth:`~pyrogram.Client.get_chat`.
-
-        is_gifts_available (``bool``, *optional*):
-            True, if star gifts can be received by this chat.
-
-        is_auto_translation_enabled (``bool``, *optional*):
-            True, if automatic translation is enabled in chat.
+        is_stories_unavailable (``bool``):
+            True, if this chat stories is unavailable.
 
         title (``str``, *optional*):
             Title, for supergroups, channels and basic group chats.
@@ -91,21 +79,21 @@ class Chat(Object):
         username (``str``, *optional*):
             Username, for private chats, bots, supergroups and channels if available.
 
+        usernames (List of :obj:`~pyrogram.types.Username`, *optional*):
+            The list of chat's collectible (and basic) usernames if available.
+
         first_name (``str``, *optional*):
             First name of the other party in a private chat, for private chats and bots.
 
         last_name (``str``, *optional*):
             Last name of the other party in a private chat, for private chats.
 
+        full_name (``str``, *property*):
+            Full name of the other party in a private chat, for private chats and bots.
+
         photo (:obj:`~pyrogram.types.ChatPhoto`, *optional*):
             Chat photo. Suitable for downloads only.
 
-        stories (List of :obj:`~pyrogram.types.Story`, *optional*):
-            The list of chat's stories if available.
-
-        wallpaper (:obj:`~pyrogram.types.Document`, *optional*):
-            Chat wallpaper.
-
         bio (``str``, *optional*):
             Bio of the other party in a private chat.
             Returned only in :meth:`~pyrogram.Client.get_chat`.
@@ -120,9 +108,6 @@ class Chat(Object):
             It is accurate only in case the owner has set the chat photo, otherwise the dc_id will be the one assigned
             to the administrator who set the current chat photo.
 
-        folder_id (``int``, *optional*):
-            The folder identifier where the chat is located.
-
         has_protected_content (``bool``, *optional*):
             True, if messages from the chat can't be forwarded to other chats.
 
@@ -146,14 +131,6 @@ class Chat(Object):
             Chat members count, for groups, supergroups and channels only.
             Returned only in :meth:`~pyrogram.Client.get_chat`.
 
-        join_requests_count (``int``, *optional*):
-            Number of users who requested to join the chat.
-            Returned only in :meth:`~pyrogram.Client.get
-
-        slow_mode_delay (``int``, *optional*):
-            For supergroups, the minimum allowed delay between consecutive messages sent by each unpriviledged user in seconds.
-            Returned only in :meth:`~pyrogram.Client.get_chat`.
-
         restrictions (List of :obj:`~pyrogram.types.Restriction`, *optional*):
             The list of reasons why this chat might be unavailable to some users.
             This field is available only in case *is_restricted* is True.
@@ -169,10 +146,6 @@ class Chat(Object):
             The linked discussion group (in case of channels) or the linked channel (in case of supergroups).
             Returned only in :meth:`~pyrogram.Client.get_chat`.
 
-        linked_forum (:obj:`~pyrogram.types.Chat`, *optional*):
-            The linked monoforum (in case of channels) or the linked channel (in case of monoforum).
-            Returned only in :meth:`~pyrogram.Client.get_chat`.
-
         send_as_chat (:obj:`~pyrogram.types.Chat`, *optional*):
             The default "send_as" chat.
             Returned only in :meth:`~pyrogram.Client.get_chat`.
@@ -181,13 +154,6 @@ class Chat(Object):
             Available reactions in the chat.
             Returned only in :meth:`~pyrogram.Client.get_chat`.
 
-        full_name (``str``, *property*):
-            Full name of the other party in a private chat, for private chats and bots.
-
-        usernames (List of :obj:`~pyrogram.types.Username`, *optional*):
-            List of all chat (fragment) usernames; for private chats, supergroups and channels.
-            Returned only in :meth:`~pyrogram.Client.get_chat`.
-
         level (``int``, *optional*):
             Channel boosts level.
             For channel only.
@@ -198,10 +164,6 @@ class Chat(Object):
         profile_color (:obj:`~pyrogram.types.ChatColor`, *optional*):
             Chat profile color.
 
-        birthday (:obj:`~pyrogram.types.Birthday`, *optional*):
-            User Date of birth.
-            Returned only in :meth:`~pyrogram.Client.get_chat`.
-
         personal_chat (:obj:`~pyrogram.types.Chat`, *optional*):
             For private chats, the personal channel of the user.
             Returned only in :meth:`~pyrogram.Client.get_chat`.
@@ -209,11 +171,14 @@ class Chat(Object):
         max_reaction_count (``int``):
             The maximum number of reactions that can be set on a message in the chat
 
-        subscription_until_date (:py:obj:`~datetime.datetime`, *optional*):
-            Channel members only. Date when the subscription expires.
-
         gifts_count (``int``, *optional*):
             Number of gifts received by the user.
+
+        background_emoji_id (``int``, *optional*)
+            Chat background emoji id.
+
+        birthday (:obj:`~pyrogram.types.Birthday`, *optional*):
+            User Date of birth.
     """
 
     def __init__(
@@ -222,115 +187,88 @@ class Chat(Object):
         client: "pyrogram.Client" = None,
         id: int,
         type: "enums.ChatType",
+        is_forum: bool = None,
         is_verified: bool = None,
+        is_participants_hidden: bool = None,
         is_restricted: bool = None,
         is_creator: bool = None,
         is_admin: bool = None,
         is_scam: bool = None,
         is_fake: bool = None,
+        is_deactivated: bool = None,
         is_support: bool = None,
-        is_participants_hidden: bool = None,
-        is_join_request: bool = None,
-        is_join_to_send: bool = None,
-        is_antispam: bool = None,
-        is_paid_reactions_available: bool = None,
-        is_slowmode_enabled: bool = None,
-        is_gifts_available: bool = None,
-        is_auto_translation_enabled: bool = None,
+        is_stories_hidden: bool = None,
+        is_stories_unavailable: bool = None,
         title: str = None,
         username: str = None,
+        usernames: List["types.Username"] = None,
         first_name: str = None,
         last_name: str = None,
         photo: "types.ChatPhoto" = None,
-        stories: List["types.Story"] = None,
-        wallpaper: "types.Document" = None,
         bio: str = None,
         description: str = None,
         dc_id: int = None,
-        folder_id: int = None,
         has_protected_content: bool = None,
         invite_link: str = None,
         pinned_message=None,
         sticker_set_name: str = None,
         can_set_sticker_set: bool = None,
         members_count: int = None,
-        join_requests_count: int = None,
-        slow_mode_delay: int = None,
         restrictions: List["types.Restriction"] = None,
         permissions: "types.ChatPermissions" = None,
         distance: int = None,
         linked_chat: "types.Chat" = None,
-        linked_forum: "types.Chat" = None,
         send_as_chat: "types.Chat" = None,
         available_reactions: Optional["types.ChatReactions"] = None,
-        usernames: List["types.Username"] = None,
         reply_color: "types.ChatColor" = None,
         profile_color: "types.ChatColor" = None,
-        birthday: "types.Birthday" = None,
         personal_chat: "types.Chat" = None,
-        max_reaction_count: int = None,
-        subscription_until_date: datetime = None,
-        gifts_count: int = None,
+        birthday: "types.Birthday" = None
     ):
         super().__init__(client)
 
         self.id = id
         self.type = type
+        self.is_forum = is_forum
         self.is_verified = is_verified
+        self.is_participants_hidden = is_participants_hidden
         self.is_restricted = is_restricted
         self.is_creator = is_creator
         self.is_admin = is_admin
         self.is_scam = is_scam
         self.is_fake = is_fake
+        self.is_deactivated = is_deactivated
         self.is_support = is_support
-        self.is_participants_hidden = is_participants_hidden
-        self.is_join_request = is_join_request
-        self.is_join_to_send = is_join_to_send
-        self.is_antispam = is_antispam
-        self.is_paid_reactions_available = is_paid_reactions_available
-        self.is_slowmode_enabled = is_slowmode_enabled
-        self.is_gifts_available = is_gifts_available
-        self.is_auto_translation_enabled = is_auto_translation_enabled
+        self.is_stories_hidden = is_stories_hidden
+        self.is_stories_unavailable = is_stories_unavailable
         self.title = title
         self.username = username
+        self.usernames = usernames
         self.first_name = first_name
         self.last_name = last_name
         self.photo = photo
-        self.stories = stories
-        self.wallpaper = wallpaper
         self.bio = bio
         self.description = description
         self.dc_id = dc_id
-        self.folder_id = folder_id
         self.has_protected_content = has_protected_content
         self.invite_link = invite_link
         self.pinned_message = pinned_message
         self.sticker_set_name = sticker_set_name
         self.can_set_sticker_set = can_set_sticker_set
         self.members_count = members_count
-        self.join_requests_count = join_requests_count
-        self.slow_mode_delay = slow_mode_delay
         self.restrictions = restrictions
         self.permissions = permissions
         self.distance = distance
         self.linked_chat = linked_chat
-        self.linked_forum = linked_forum
         self.send_as_chat = send_as_chat
         self.available_reactions = available_reactions
-        self.usernames = usernames
+        self.personal_chat = personal_chat
         self.reply_color = reply_color
         self.profile_color = profile_color
         self.birthday = birthday
-        self.personal_chat = personal_chat
-        self.subscription_until_date = subscription_until_date
-        self.gifts_count = gifts_count
-
-    @property
-    def full_name(self) -> str:
-        return " ".join(filter(None, [self.first_name, self.last_name])) or self.title or None
 
     @staticmethod
-    def _parse_user_chat(client, user: raw.types.User) -> Optional["Chat"]:
+    def _parse_user_chat(client, user: raw.types.User) -> "Chat":
         if user is None or isinstance(user, raw.types.UserEmpty):
             return None
         peer_id = user.id
@@ -344,6 +282,7 @@ class Chat(Object):
             is_fake=getattr(user, "fake", None),
             is_support=getattr(user, "support", None),
             username=user.username,
+            usernames=types.List([types.Username._parse(r) for r in user.usernames]) or None,
             first_name=user.first_name,
             last_name=user.last_name,
             photo=types.ChatPhoto._parse(client, user.photo, peer_id, user.access_hash),
@@ -355,17 +294,12 @@ class Chat(Object):
         )
 
     @staticmethod
-    def _parse_chat_chat(client, chat: raw.types.Chat) -> Optional["Chat"]:
+    def _parse_chat_chat(client, chat: raw.types.Chat) -> "Chat":
         if chat is None or isinstance(chat, raw.types.ChatEmpty):
             return None
         peer_id = -chat.id
-        active_usernames = getattr(chat, "usernames", [])
+        usernames = getattr(chat, "usernames", [])
         admin_rights = getattr(chat, "admin_rights", None)
-        usernames = None
-        if len(active_usernames) >= 1:
-            usernames = []
-            for username in active_usernames:
-                usernames.append(types.Username._parse(username))
 
         return Chat(
             id=peer_id,
@@ -373,64 +307,40 @@ class Chat(Object):
             title=chat.title,
             is_creator=getattr(chat, "creator", None),
             is_admin=True if admin_rights else None,
-            usernames=usernames,
+            is_deactivated=getattr(chat, "deactivated", None),
+            usernames=types.List([types.Username._parse(r) for r in usernames]) or None,
             photo=types.ChatPhoto._parse(client, getattr(chat, "photo", None), peer_id, 0),
             permissions=types.ChatPermissions._parse(getattr(chat, "default_banned_rights", None)),
             members_count=getattr(chat, "participants_count", None),
-            join_requests_count=getattr(chat, "requests_pending", None),
             dc_id=getattr(getattr(chat, "photo", None), "dc_id", None),
             has_protected_content=getattr(chat, "noforwards", None),
             client=client
         )
 
     @staticmethod
-    def _parse_channel_chat(client, channel: raw.types.Channel) -> Optional["Chat"]:
+    def _parse_channel_chat(client, channel: raw.types.Channel) -> "Chat":
         if channel is None:
             return None
         peer_id = utils.get_channel_id(channel.id)
         restriction_reason = getattr(channel, "restriction_reason", [])
-        user_name = getattr(channel, "username", None)
-        active_usernames = getattr(channel, "usernames", [])
+        usernames = getattr(channel, "usernames", [])
         admin_rights = getattr(channel, "admin_rights", None)
-        if getattr(channel, "monoforum", None):
-            chat_type = enums.ChatType.MONOFORUM
-        elif getattr(channel, "forum", None):
-            chat_type = enums.ChatType.FORUM
-        elif getattr(channel, "megagroup", None):
-            chat_type = enums.ChatType.SUPERGROUP
-        elif getattr(channel, "broadcast", None):
-            chat_type = enums.ChatType.CHANNEL
-        else:
-            chat_type = enums.ChatType.GROUP
-        usernames = None
-        if len(active_usernames) >= 1:
-            usernames = []
-            for username in active_usernames:
-                if username.editable:
-                    user_name = username.username
-                else:
-                    usernames.append(types.Username._parse(username))
-        if user_name is None and usernames is not None and len(usernames) > 0:
-            user_name = usernames[0].username
-            usernames.pop(0)
-        subscription_until = getattr(channel, "subscription_until_date", None)
-        subscription_until_date = utils.timestamp_to_datetime(subscription_until) if subscription_until is not None else None
 
         return Chat(
             id=peer_id,
-            type=chat_type,
+            type=enums.ChatType.SUPERGROUP if getattr(channel, "megagroup", None) else enums.ChatType.CHANNEL,
+            is_forum=getattr(channel, "forum", None),
             is_verified=getattr(channel, "verified", None),
             is_restricted=getattr(channel, "restricted", None),
             is_creator=getattr(channel, "creator", None),
             is_admin=True if admin_rights else None,
             is_scam=getattr(channel, "scam", None),
             is_fake=getattr(channel, "fake", None),
-            is_join_request=getattr(channel, "join_request", None),
-            is_join_to_send=getattr(channel, "join_to_send", None),
-            is_slowmode_enabled=getattr(channel, "slowmode_enabled", None),
+            is_stories_hidden=getattr(channel, "stories_hidden", None),
+            is_stories_unavailable=getattr(channel, "stories_unavailable", None),
             title=channel.title,
-            username=user_name,
-            usernames=usernames,
+            username=getattr(channel, "username", None),
+            usernames=types.List([types.Username._parse(r) for r in usernames]) or None,
             photo=types.ChatPhoto._parse(client, getattr(channel, "photo", None), peer_id,
                                          getattr(channel, "access_hash", 0)),
             restrictions=types.List([types.Restriction._parse(r) for r in restriction_reason]) or None,
@@ -439,7 +349,6 @@ class Chat(Object):
             dc_id=getattr(getattr(channel, "photo", None), "dc_id", None),
             has_protected_content=getattr(channel, "noforwards", None),
             reply_color=types.ChatColor._parse(getattr(channel, "color", None)),
-            subscription_until_date=subscription_until_date,
             client=client
         )
 
@@ -447,8 +356,8 @@ class Chat(Object):
     def _parse(
         client,
         message: Union[raw.types.Message, raw.types.MessageService],
-        users: Dict[int, "raw.types.User"],
-        chats: Dict[int, "raw.types.Chat"],
+        users: dict,
+        chats: dict,
         is_chat: bool
     ) -> "Chat":
         from_id = utils.get_raw_peer_id(message.from_id)
@@ -456,27 +365,64 @@ class Chat(Object):
         chat_id = (peer_id or from_id) if is_chat else (from_id or peer_id)
 
         if isinstance(message.peer_id, raw.types.PeerUser):
-            return Chat._parse_user_chat(client, users[chat_id])
+            return Chat._parse_user_chat(client, users.get(chat_id))
 
-        if isinstance(message.peer_id, raw.types.PeerChat):
-            return Chat._parse_chat_chat(client, chats[chat_id])
+        elif isinstance(message.peer_id, raw.types.PeerChat):
+            return Chat._parse_chat_chat(client, chats.get(chat_id))
+        else:
+            return Chat._parse_channel_chat(client, chats.get(chat_id))
+        
+    @staticmethod
+    async def _parse_with_fallback(
+        client,
+        message: Union[raw.types.Message, raw.types.MessageService],
+        users: dict,
+        chats: dict,
+        is_chat: bool
+    ) -> "Chat":
+        from_id = utils.get_raw_peer_id(message.from_id)
+        peer_id = utils.get_raw_peer_id(message.peer_id)
+        chat_id = (peer_id or from_id) if is_chat else (from_id or peer_id)
+
+        if isinstance(message.peer_id, raw.types.PeerUser):
+            user_data = users.get(chat_id)
+            if not user_data:
+                try:
+                    chat_obj = await client.get_chat(chat_id)
+                    users[chat_obj.id] = chat_obj
+                    user_data = users.get(chat_id)
+                except Exception:
+                    return None
+            return Chat._parse_user_chat(client, user_data)
+
+        elif isinstance(message.peer_id, raw.types.PeerChat):
+            chat_data = chats.get(chat_id)
+            if not chat_data:
+                try:
+                    chat_obj = await client.get_chat(chat_id)
+                    chats[chat_obj.id] = chat_obj
+                    chat_data = chats.get(chat_id)
+                except Exception:
+                    return None
+            return Chat._parse_chat_chat(client, chat_data)
+
+        else:
+            channel_data = chats.get(chat_id)
+            if not channel_data:
+                try:
+                    chat_obj = await client.get_chat(chat_id)
+                    chats[chat_obj.id] = chat_obj
+                    channel_data = chats.get(chat_id)
+                except Exception:
+                    return None
+            return Chat._parse_channel_chat(client, channel_data)
 
-        return Chat._parse_channel_chat(client, chats[chat_id])
 
     @staticmethod
-    def _parse_dialog(
-        client,
-        peer: Union[
-            raw.types.PeerUser,
-            raw.types.PeerChat,
-            raw.types.PeerChannel
-        ],
-        users: Dict[int, "raw.types.User"],
-        chats: Dict[int, "raw.types.Chat"]
-    ) -> "Chat":
-        if isinstance(peer, raw.types.PeerUser) or isinstance(peer, raw.types.InputPeerUser):
+    def _parse_dialog(client, peer, users: dict, chats: dict):
+        if isinstance(peer, raw.types.PeerUser):
             return Chat._parse_user_chat(client, users[peer.user_id])
-        elif isinstance(peer, raw.types.PeerChat) or isinstance(peer, raw.types.InputPeerChat):
+        elif isinstance(peer, raw.types.PeerChat):
             return Chat._parse_chat_chat(client, chats[peer.chat_id])
         else:
             return Chat._parse_channel_chat(client, chats[peer.channel_id])
@@ -491,37 +437,12 @@ class Chat(Object):
 
             parsed_chat = Chat._parse_user_chat(client, users[full_user.id])
             parsed_chat.bio = full_user.about
-            parsed_chat.birthday = types.Birthday._parse(getattr(full_user, "birthday", None))
-            parsed_chat.gifts_count = getattr(full_user, "stargifts_count", None)
-            personal_chat_id = getattr(full_user, "personal_channel_id", None)
-
-            if personal_chat_id is not None:
-                personal_chat = await client.invoke(
-                    raw.functions.channels.GetChannels(
-                        id=[await client.resolve_peer(utils.get_channel_id(personal_chat_id))]
-                    )
-                )
-                parsed_chat.personal_chat = Chat._parse_chat(client, personal_chat.chats[0])
 
             if full_user.pinned_msg_id:
                 parsed_chat.pinned_message = await client.get_messages(
                     parsed_chat.id,
                     message_ids=full_user.pinned_msg_id
                 )
-            if getattr(full_user, "stories"):
-                peer_stories: raw.types.PeerStories = full_user.stories
-                parsed_chat.stories = types.List(
-                    [
-                        await types.Story._parse(
-                            client, story, peer_stories.peer
-                        )
-                        for story in peer_stories.stories
-                    ]
-                ) or None
-
-            if getattr(full_user, "wallpaper") and isinstance(full_user.wallpaper, raw.types.WallPaper):
-                parsed_chat.wallpaper = types.Document._parse(client, full_user.wallpaper.document, "wallpaper.jpg")
-            
         else:
             full_chat = chat_full.full_chat
             chat_raw = chats[full_chat.id]
@@ -532,32 +453,20 @@ class Chat(Object):
 
                 if isinstance(full_chat.participants, raw.types.ChatParticipants):
                     parsed_chat.members_count = len(full_chat.participants.participants)
-                parsed_chat.join_requests_count = getattr(full_chat, "requests_pending", None)
             else:
                 parsed_chat = Chat._parse_channel_chat(client, chat_raw)
                 parsed_chat.members_count = full_chat.participants_count
-                parsed_chat.join_requests_count = getattr(full_chat, "requests_pending", None)
-                parsed_chat.slow_mode_delay = getattr(full_chat, "slowmode_seconds", None)
                 parsed_chat.description = full_chat.about or None
                 # TODO: Add StickerSet type
                 parsed_chat.can_set_sticker_set = full_chat.can_set_stickers
                 parsed_chat.sticker_set_name = getattr(full_chat.stickerset, "short_name", None)
                 parsed_chat.is_participants_hidden = full_chat.participants_hidden
-                parsed_chat.is_antispam = full_chat.antispam
-                parsed_chat.is_paid_reactions_available = full_chat.paid_reactions_available
-                parsed_chat.is_gifts_available = getattr(full_chat, "stargifts_available", None)
-                parsed_chat.is_auto_translation_enabled = getattr(full_chat, "auto_translation", None)
-                parsed_chat.gifts_count = getattr(full_chat, "stargifts_count", None)
-                parsed_chat.folder_id = getattr(full_chat, "folder_id", None)
 
                 linked_chat_raw = chats.get(full_chat.linked_chat_id, None)
-                linked_forum_raw = chats.get(getattr(chat_raw, "linked_monoforum_id"), None)
+
                 if linked_chat_raw:
                     parsed_chat.linked_chat = Chat._parse_channel_chat(client, linked_chat_raw)
 
-                if linked_forum_raw:
-                    parsed_chat.linked_forum = Chat._parse_channel_chat(client, linked_forum_raw)
-
                 default_send_as = full_chat.default_send_as
 
                 if default_send_as:
@@ -567,19 +476,6 @@ class Chat(Object):
                         send_as_raw = chats[default_send_as.channel_id]
 
                     parsed_chat.send_as_chat = Chat._parse_chat(client, send_as_raw)
-                
-                if getattr(full_chat, "stories"):
-                    parsed_chat.stories = types.List(
-                        [
-                            await types.Story._parse(
-                                client, story, full_chat.stories.peer
-                            )
-                            for story in full_chat.stories.stories
-                        ]
-                    ) or None
-
-                if getattr(full_chat, "wallpaper") and isinstance(full_chat.wallpaper, raw.types.WallPaper):
-                    parsed_chat.wallpaper = types.Document._parse(client, full_chat.wallpaper.document, "wallpaper.jpg")
 
             if full_chat.pinned_msg_id:
                 parsed_chat.pinned_message = await client.get_messages(
@@ -590,23 +486,23 @@ class Chat(Object):
             if isinstance(full_chat.exported_invite, raw.types.ChatInviteExported):
                 parsed_chat.invite_link = full_chat.exported_invite.link
 
-            parsed_chat.available_reactions = types.ChatReactions._parse(
-                client,
-                full_chat.available_reactions
-            )
-            parsed_chat.max_reaction_count = getattr(full_chat, "reactions_limit", 11)
+            parsed_chat.available_reactions = types.ChatReactions._parse(client, full_chat.available_reactions)
 
         return parsed_chat
 
     @staticmethod
     def _parse_chat(client, chat: Union[raw.types.Chat, raw.types.User, raw.types.Channel]) -> "Chat":
-        if isinstance(chat, (raw.types.Chat, raw.types.ChatForbidden)):
+        if isinstance(chat, raw.types.Chat):
             return Chat._parse_chat_chat(client, chat)
         elif isinstance(chat, raw.types.User):
             return Chat._parse_user_chat(client, chat)
         else:
             return Chat._parse_channel_chat(client, chat)
 
+    @property
+    def full_name(self) -> str:
+        return " ".join(filter(None, [self.first_name, self.last_name])) or None
+
     async def archive(self):
         """Bound method *archive* of :obj:`~pyrogram.types.Chat`.
 
@@ -792,8 +688,7 @@ class Chat(Object):
     async def ban_member(
         self,
         user_id: Union[int, str],
-        until_date: datetime = utils.zero_datetime(),
-        revoke_messages: bool = None
+        until_date: datetime = utils.zero_datetime()
     ) -> Union["types.Message", bool]:
         """Bound method *ban_member* of :obj:`~pyrogram.types.Chat`.
 
@@ -826,10 +721,6 @@ class Chat(Object):
                 If user is banned for more than 366 days or less than 30 seconds from the current time they are
                 considered to be banned forever. Defaults to epoch (ban forever).
 
-            revoke_messages (``bool``, *optional*):
-                Pass True to delete all messages from the chat for the user that is being removed. If False, the user will be able to see messages in the group that were sent before the user was removed.
-                Always True for supergroups and channels.
-
         Returns:
             :obj:`~pyrogram.types.Message` | ``bool``: On success, a service message will be returned (when applicable), otherwise, in
             case a message object couldn't be returned, True is returned.
@@ -841,8 +732,7 @@ class Chat(Object):
         return await self._client.ban_chat_member(
             chat_id=self.id,
             user_id=user_id,
-            until_date=until_date,
-            revoke_messages=revoke_messages
+            until_date=until_date
         )
 
     async def unban_member(
@@ -937,8 +827,7 @@ class Chat(Object):
     async def promote_member(
         self,
         user_id: Union[int, str],
-        privileges: "types.ChatPrivileges" = None,
-        title: Optional[str] = "",
+        privileges: "types.ChatPrivileges" = None
     ) -> bool:
         """Bound method *promote_member* of :obj:`~pyrogram.types.Chat`.
 
@@ -948,8 +837,7 @@ class Chat(Object):
 
             await client.promote_chat_member(
                 chat_id=chat_id,
-                user_id=user_id,
-                title=admin_title
+                user_id=user_id
             )
 
         Example:
@@ -965,11 +853,6 @@ class Chat(Object):
 
             privileges (:obj:`~pyrogram.types.ChatPrivileges`, *optional*):
                 New user privileges.
-            
-            title (``str``, *optional*):
-                A custom title that will be shown to all members instead of "Owner" or "Admin".
-                Pass None or "" (empty string) will keep the current title.
-                If you want to delete the custom title, use :meth:`~pyrogram.Client.set_administrator_title()` method.
 
         Returns:
             ``bool``: True on success.
@@ -981,8 +864,7 @@ class Chat(Object):
         return await self._client.promote_chat_member(
             chat_id=self.id,
             user_id=user_id,
-            privileges=privileges,
-            title=title
+            privileges=privileges
         )
 
     async def join(self):
